@@ -151,22 +151,6 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         for tag in tags_data:
             data[tag.key] = tag.val
 
-        import tornado.ioloop
-        import tornado.web
-
-        class MainHandler(tornado.web.RequestHandler):
-            def get(self):
-                self.write("Hello, world")
-
-        def make_app():
-            return tornado.web.Application([
-                (r"/", MainHandler),
-            ])
-
-        if __name__ == "__main__":
-            app = make_app()
-            app.listen(8888)
-            tornado.ioloop.IOLoop.current().start()
         return data
 
     def convert_logs(self, logs_data):
