@@ -16,6 +16,7 @@ from fast_tracker.utils.reader_type import ReaderType
 
 
 def install():
+    # todo: 后续需要对此插件做版本控制，现在仅支持5.1.1版本， 6+没支持
     from tornado.web import RequestHandler
 
     old_execute = RequestHandler._execute
@@ -84,8 +85,11 @@ def _gen_fast_get_response_func(old_execute):
             with context.new_entry_span(op=request.path, carrier=carrier) as span:
                 span.layer = Layer.Http
                 span.component = ComponentType.Tornado
+                # v6+use this
                 # peer = request.connection.stream.socket.getpeername()
-                peer = self.stream.socket.getpeername()
+                # peer = self.stream.socket.getpeername()
+                # v5.1.1 use this
+                peer = self.request.connection.context.address  # peer1: ('::1', 52857, 0, 0)
                 span.peer = "{0}:{1}".format(*peer)
                 span.tag(Tag(key=tags.HttpMethod, val=request.method))
                 span.tag(Tag(key=tags.HttpUrl, val="{}://{}{}".format(request.protocol, request.host, request.path)))
@@ -118,12 +122,18 @@ def set_code(reader, request, type="tenant_code"):
     reader_key = reader.get("ReaderKey")
 
     if reader_type == ReaderType.Cookie:
-        code = request.get_cookie(reader_key, "")
+        # # tornado6.0.4 is ok
+        # code = request.get_cookie(reader_key, "")
+        # tornado5.1.1 is ok
+        code = request.cookies.get(reader_key, "")
     elif reader_type == ReaderType.RequestHeader:
         code = request.headers[reader_key] if reader_key in request.headers else ""
     elif reader_type == ReaderType.QueryString:
         # data = json.loads(request.body.decode('utf-8'))
-        code = request.get_argument(reader_key, default="") if request.arguments.has_key(reader_key) else ""
+        # # tornado6.0.4 is ok
+        # code = request.get_argument(reader_key, default="") if request.arguments.has_key(reader_key) else ""
+        # tornado5.1.1
+        code = request.arguments.get(reader_key, "")
     elif reader_type == ReaderType.Environment:
         import os
 
